/**
 * OW2 Util
 * Copyright (C) 2008 Bull S.A.S.
 * Contact: easybeans@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 *
 * --------------------------------------------------------------------------
 * $Id: ISession.java 4389 2008-12-15 13:48:57Z alitokmen $
 * --------------------------------------------------------------------------
 */

package org.ow2.util.ee.metadata.ejbjar.api.xml.struct;

import java.util.List;

/**
 * Interface for element session.
 * @author Florent Benoit
 */
public interface ISession extends IBean {

    /**
     * Name of this element.
     */
    String NAME = "session";

    /**
     * Gets the business-remote interface list.
     * @return business-remote interface list
     */
    List<String> getBusinessRemoteList();

    /**
     * Gets the business-local interface list.
     * @return business-local interface list
     */
    List<String> getBusinessLocalList();

    /**
     * Add the business-remote interface.
     * @param businessRemote business-remote interface.
     */
    void addBusinessRemote(final String businessRemote);

    /**
     * Add the business-local interface.
     * @param businessLocal business-remote interface.
     */
    void addBusinessLocal(final String businessLocal);

    /**
     * Gets the list of remove methods.
     * @return list of remove methods
     */
    List<IRemoveMethod> getRemoveMethodList();

    /**
     * Add the method used as a remove method.
     * @param removeMethod the given remove method
     */
    void addRemoveMethod(final IRemoveMethod removeMethod);

    /**
     * Gets the session-type.
     * @return the session-type.
     */
    String getSessionType();

    /**
     * Set the session-type.
     * @param sessionType the type of session.
     */
    void setSessionType(final String sessionType);

    /**
     * Gets the remote Home.
     * @return the remote Home
     */
    String getRemoteHome();

    /**
     * Set the remote Home.
     * @param remoteHome the given remote Home.
     */
    void setRemoteHome(final String remoteHome);

    /**
     * Gets the local Home.
     * @return the local Home
     */
    String getLocalHome();

    /**
     * Set the local Home.
     * @param localHome the given local Home.
     */
    void setLocalHome(final String localHome);

}
